@@ -6,7 +6,7 @@ from .. import filtersets
 
 
 class RiskListViewSet(NetBoxModelViewSet):
-    queryset = models.Risk.objects.prefetch_related('tags')
+    queryset = models.Aduser.objects.prefetch_related('tags')
     serializer_class = RiskSerializer
 
 
