@@ -1,6 +1,6 @@
 import django_tables2 as tables
 from netbox.tables import NetBoxTable, columns
-from .models import Risk, RiskRelation, RiskAssignment
+from .models import Aduser, RiskRelation, RiskAssignment
 
 
 class RiskTable(NetBoxTable):
@@ -10,9 +10,16 @@ class RiskTable(NetBoxTable):
     # default_action = ChoiceFieldColumn()
 
     class Meta(NetBoxTable.Meta):
-        model = Risk
-        fields = ('pk', 'name', 'description')
-        default_columns = ('name', 'description')
+        model = Aduser
+        fields = ('pk', 'name', 'sAMAccountName',
+                  'status',
+                  'firstname',
+                  'lastname', 'ad_guid', 'ad_description', 'position', 'department', 'comment',
+                  'vpnIPaddress', 'description')
+        default_columns = ('name', 'sAMAccountName',
+                  'status',
+                  'firstname',
+                  'lastname', 'ad_guid', 'description')
 
 
 class RiskRelationTable(NetBoxTable):
